:orphan:

SQLAlchemy 2.0 Future (Core)
============================

.. admonition:: We're 2.0!

    This page described the "future" mode provided in SQLAlchemy 1.4
    for the purposes of 1.4 -> 2.0 transition.   For 2.0, the "future"
    parameter on :func:`_sa.create_engine` and :class:`_orm.Session`
    continues to remain available for backwards-compatibility support, however
    if specified must be left at the value of ``True``.

    .. seealso::

        :ref:`migration_20_toplevel` - Introduction to the 2.0 series of SQLAlchemy

